xoa - xarray-based ocean analysis library
=========================================

.. image:: https://anaconda.org/conda-forge/xoa/badges/installer/conda.svg
    :alt: Install with conda
    :target: https://conda.anaconda.org/conda-forge
.. image:: https://github.com/VACUMM/xoa/actions/workflows/python-package-conda.yml/badge.svg
    :alt: Install, linting and tests
.. image:: https://readthedocs.org/projects/docs/badge/?version=latest
    :alt: Documentation Status
    :target: https://xoa.readthedocs.io/en/latest/
.. image:: https://anaconda.org/conda-forge/xoa/badges/downloads.svg
    :alt: Number of downloads on anaconda.org/conda-forge
    :target: https://anaconda.org/conda-forge/xoa/
.. image:: https://pepy.tech/badge/xoa
    :alt: Number of downloads on pypi
    :target: https://pypi.org/project/xoa

xoa is intended to help reading and manipulating observed
and simulated ocean data.
It is heavily based on `xarray <http://xarray.pydata.org/en/stable/>`_.
For those who know it, it is the successor of
`vacumm <https://github.com/VACUMM/vacumm>`_.

Documentation
-------------

The xoa documentation is currently generated and hosted by readthedocs:
https://xoa.readthedocs.io

Sources and help
-----------------

Sources are available on the xoa github page:
https://github.com/VACUMM/xoa.
Here you can also
participate to `discussions <https://github.com/VACUMM/xoa/discussions>`_
and post tickets for
`requests <https://github.com/VACUMM/xoa/pulls>`_ and
`issues <https://github.com/VACUMM/xoa/issues>`_.

License
-------

xoa is a property of `Shom <https://www.shom.fr>`_
and is published under the
`Apache 2.0 license <https://www.apache.org/licenses/LICENSE-2.0>`_.
